@extends('layouts.panel')

@section('css')
    <link href="{{ asset('assets/css/checkbox.css') }}" rel="stylesheet">
@endsection

@section('page', 'Security')

@section('navigation')
                <li class="active treeview menu-open">
                    <a>
                        <i class="fas fa-user"></i> <span>Account</span>
                        <span class="pull-right-container"><i class="fa fa-angle-left pull-right"></i></span>
                    </a>
                    <ul class="treeview-menu">
                        <li><a href="{{ route('panel.profile') }}"><i class="fas fa-id-badge"></i> Profile</a></li>
                        <li class="active"><a><i class="fas fa-clipboard"></i> Change</a></li>
                        <li class="hidden-xs"><a href="{{ route('panel.security') }}"><i class="fas fa-lock"></i> Security</a></li>
                    </ul>
                </li>
                <li class="header">NAVIGATION</li>
                <li>
                    <a href="{{ route('panel.home') }}"><i class="fas fa-tachometer-alt"></i> <span>Dashboard</span></a>
                </li>
                @canany(['project_see', 'status_see'])
                <li class="treeview">
                    <a>
                        <i class="fas fa-list"></i> <span>Projects</span>
                        <span class="pull-right-container"><i class="fa fa-angle-left pull-right"></i></span>
                    </a>
                    <ul class="treeview-menu">
                        @can('project_see')<li><a href="{{ route('panel.project') }}"><i class="fas fa-clipboard"></i> Project</a></li>@endcan
                        @can('order_see')<li><a href="{{ route('panel.order') }}"><i class="fas fa-file-invoice"></i> Order</a></li>@endcan
                        @can('status_see')<li><a href="{{ route('panel.status') }}"><i class="fas fa-clipboard"></i> Status</a></li>@endcan
                    </ul>
                </li>
                @endcanany
                @canany(['roles_see', 'user_see'])
                <li class="treeview">
                    <a>
                        <i class="fas fa-user"></i> <span>Management</span>
                        <span class="pull-right-container"><i class="fa fa-angle-left pull-right"></i></span>
                    </a>
                    <ul class="treeview-menu">
                        @can('user_see')<li><a href="{{ route('panel.ums') }}"><i class="fas fa-id-badge"></i> Users</a></li>@endcan
                        @can('roles_see')<li><a href="{{ route('panel.role') }}"><i class="fas fa-lock"></i> Roles</a></li>@endcan
                    </ul>
                </li>
                @endcanany
@endsection

@section('content')
            <div class="row">
                <div class="col-xs-12 col-md-4">
                    <div class="box box-primary">
                        <div class="box-header with-border">
                            <h3 class="box-title">Change Password</h3>
                        </div>
                        <div class="box-body">
                            <form method="POST" action="{{ route('panel.change.password') }}" class="col-xs-10 col-xs-offset-1">
                                @csrf

                                @if(session('pass_success'))
                                    <div class="alert alert-success" role="alert">
                                        {{ session('pass_success') }}
                                        <a class="close" data-dismiss="alert" aria-label="close">&times;</a>
                                    </div>

                                @endif
                                <div class="form-group @error('pass_password') has-error @enderror">
                                    <label for="pass_password" class="text-md-right">{{ __('Current Password:') }}</label>

                                    <div class="input-group">
                                        <span class="input-group-addon"><i class="glyphicon glyphicon-lock"></i></span>
                                        <input id="pass_password" type="password" class="form-control" placeholder="Current Password" name="password" required autocomplete="off" autofocus>
                                    </div>
                                    @error('pass_password')
                                    <span class="help-block">{{ $message }}</span>
                                    @enderror
                                </div>

                                <div class="form-group @error('new_password') has-error @enderror">
                                    <label for="new_password" class="text-md-right">{{ __('New Password:') }}</label>

                                    <div class="input-group">
                                        <span class="input-group-addon"><i class="glyphicon glyphicon-lock"></i></span>
                                        <input id="new_password" type="password" class="form-control" placeholder="New Password" name="new_password" required autocomplete="off" autofocus>
                                    </div>
                                    @error('new_password')
                                    <span class="help-block">{{ $message }}</span>
                                    @enderror
                                </div>

                                <div class="form-group @error('new_confirm_password') has-error @enderror">
                                    <div class="input-group">
                                        <span class="input-group-addon"><i class="glyphicon glyphicon-lock"></i></span>
                                        <input id="new_confirm_password" type="password" class="form-control" placeholder="Confirm New Password" name="new_confirm_password" required autocomplete="off" autofocus>
                                    </div>
                                    @error('new_confirm_password')
                                    <span class="help-block">{{ $message }}</span>
                                    @enderror
                                </div>

                                <button type="submit" class="btn btn-block btn-primary">{{ __('Change Password') }}</button>
                            </form>
                        </div>
                    </div>
                </div>
                <div class="col-xs-12 col-md-4">
                    <div class="box box-primary">
                        <div class="box-header with-border">
                            <h3 class="box-title">Change Profile</h3>
                        </div>
                        <div class="box-body">
                            <form method="POST" action="{{ route('panel.change.profile') }}" enctype="multipart/form-data" class="col-xs-10 col-xs-offset-1">
                                @csrf

                                @if(session('image_success'))
                                <div class="alert alert-success" role="alert">
                                    {{ session('image_success') }}
                                    <a class="close" data-dismiss="alert" aria-label="close">&times;</a>
                                </div>

                                @elseif(session('image_error'))
                                <div class="alert alert-danger" role="alert">
                                    {{ session('image_error') }}
                                    <a class="close" data-dismiss="alert" aria-label="close">&times;</a>
                                </div>

                                @endif
                                <div class="form-group @error('image') has-error @enderror">
                                    <label for="file">Choose Image:</label>
                                    <input type="file" id="file" name="image" accept="image/*">
                                    @error('image')
                                    <span class="help-block">{{ $message }}</span>
                                    @enderror
                                </div>

                                @if(Auth::user()->image_changed)
                                <div class="checkbox">
                                    <label>
                                        <strong>{{ __('Or Reset:') }}</strong>
                                        <input type="checkbox" name="reset-image">
                                        <span class="cr"><i class="cr-icon glyphicon glyphicon-ok"></i></span>
                                    </label>
                                </div>
                                @endif

                                <button type="submit" class="btn btn-block btn-primary">{{ __('Change Profile') }}</button>
                            </form>
                        </div>
                    </div>
                </div>
                <div class="col-xs-12 col-md-4">
                    <div class="box box-primary">
                        <div class="box-header with-border">
                            <h3 class="box-title">Change Email</h3>
                        </div>
                        <div class="box-body">
                            <form method="POST" action="{{ route('panel.change.email') }}" class="col-xs-10 col-xs-offset-1">
                                @csrf

                                @if(session('email_success'))
                                <div class="alert alert-success" role="alert">
                                    {{ session('email_success') }}
                                    <a class="close" data-dismiss="alert" aria-label="close">&times;</a>
                                </div>

                                @endif
                                <div class="form-group @error('email_password') has-error @enderror">
                                    <label for="email_password" class="text-md-right">{{ __('Current Password:') }}</label>

                                    <div class="input-group">
                                        <span class="input-group-addon"><i class="glyphicon glyphicon-lock"></i></span>
                                        <input id="email_password" type="password" class="form-control" placeholder="Current Password" name="password" required autocomplete="off" autofocus>
                                    </div>
                                    @error('email_password')
                                    <span class="help-block">{{ $message }}</span>
                                    @enderror
                                </div>

                                <div class="form-group @error('new_email') has-error @enderror">
                                    <label for="new_email" class="text-md-right">{{ __('New Email:') }}</label>

                                    <div class="input-group">
                                        <span class="input-group-addon"><i class="glyphicon glyphicon-envelope"></i></span>
                                        <input id="new_email" type="email" class="form-control" placeholder="New Email" name="new_email" required autocomplete="off" autofocus>
                                    </div>
                                    @error('new_email')
                                    <span class="help-block">{{ $message }}</span>
                                    @enderror
                                </div>

                                <div class="form-group @error('new_confirm_email') has-error @enderror">
                                    <div class="input-group">
                                        <span class="input-group-addon"><i class="glyphicon glyphicon-envelope"></i></span>
                                        <input id="new_confirm_email" type="email" class="form-control" placeholder="Confirm New Email" name="new_confirm_email" required autocomplete="off" autofocus>
                                    </div>
                                    @error('new_confirm_email')
                                    <span class="help-block">{{ $message }}</span>
                                    @enderror
                                </div>

                                <button type="submit" class="btn btn-block btn-primary">{{ __('Change Email') }}</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
@endsection

@section('javascript')
<script src="{{ asset('assets/js/bootstrap-filestyle.min.js') }}"></script>
<script>
$('#file').filestyle({
    iconName : 'glyphicon glyphicon-picture',
    buttonText : 'Select File',
    buttonName : 'btn-primary'
});
</script>
<script>
window.onload = function() {
    const passInput = document.getElementById('new_confirm_password');
    passInput.onpaste = function(e) {
        e.preventDefault();
    };

    const emailInput = document.getElementById('new_confirm_email');
    emailInput.onpaste = function(e) {
        e.preventDefault();
    };
};
</script>
@endsection
